import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

ListView {
    id: questionList
    anchors.fill: parent
    anchors.margins: units.gu(2)

    model: StackListModel {
         id: questionFeed
         path: "questions/" + questionViewer.question
         query: "$.items[*]"
         args: "filter=!--btTK8(xvrs&sort=votes"
         site: stackView.site
     }
    delegate: Column {
        id: questionItemDelegate
        width: parent.width
        anchors.centerIn: parent

        Item {
            id: question_header
            width: parent.width - units.gu(2)
            height: units.gu(12)

            UbuntuShape{
                id: question_score
                color: model.accepted_answer_id ? "green" : "gray"
                anchors.margins: units.gu(2)

                Label{
                    anchors.centerIn: parent
                    fontSize: "x-large"
                    text: model.score
                    color: "white"
                }
            }

            Label {
                text: model.title
                width: parent.width - question_score.width
                anchors.left: question_score.right
                anchors.margins: units.gu(2)
                fontSize: "large"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }

        Row {
            width: parent.width - units.gu(4)

            UbuntuShape{
                color: "white"
                width: parent.width
                height: question_body.paintedHeight
                anchors.margins: units.gu(2)

                Label {
                    id: question_body
                    text: model.body
                    width: parent.width - units.gu(2)
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                }
            }
        }

        Label {
            text: "Asked by: <b>" + model.owner['display_name'] + "</b> (Reputation: <b>" + model.owner['reputation'] + "</b>)"
            height: units.gu(4)
        }

        ListItem.Divider {
            anchors.topMargin: units.gu(2)
        }

        Label {
            text: "Answers"
            height: units.gu(6)
            fontSize: "x-large"
        }

        Component {
            id: answererComponent

            Item {
                property var owner: ''
                property var rep: ''
                property var score: ''
                property bool accepted:undefined
                width: parent.width - units.gu(4)
                height: units.gu(6)

                UbuntuShape{
                    id: answer_score
                    color: accepted ? "green" : "gray"
                    anchors.margins: units.gu(2)
                    height: units.gu(5)
                    width: units.gu(5)

                    Label{
                        anchors.centerIn: parent
                        fontSize: "large"
                        text: score
                        color: "white"
                    }
                }

                Label {
                    id: answerer
                    text: "           by: <b>" + owner + "</b> (Reputation: <b>" + rep + "</b>)"
                    anchors.left: answer_score.right
                    anchors.verticalCenter: answer_score.verticalCenter
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                }
            }
        }

        Component {
            id: answerBodyComponent

            Item {
                property var body: ''

                width: parent.width - units.gu(4)
                height: answer_body.paintedHeight + units.gu(5)

                UbuntuShape{
                    color: "white"
                    width: parent.width
                    height: answer_body.paintedHeight
                    radius: "small"
                    anchors.margins: units.gu(2)

                    Label {
                        id: answer_body
                        text: body
                        width: parent.width - units.gu(4)
                        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    }
                }
            }
        }

        Component.onCompleted: {
            if (model.answer_count > 0 && model.answers){
                for (var i=0; i<model.answer_count; i++){
                    var answerer = answererComponent.createObject(questionItemDelegate)
                    var answer = answerBodyComponent.createObject(questionItemDelegate)
                    answer.body = model.answers.get(i).body
                    answerer.accepted = model.answers.get(i)["is_accepted"]
                    answerer.score = model.answers.get(i)["score"]
                    answerer.owner = model.answers.get(i).owner['display_name']
                    answerer.rep = model.answers.get(i).owner['reputation']
                }
            }
        }
    }
}
